==> lima-swing-0.7-sources.jar: org/chorem/lima/ui/common/CellRouteVerticalAction.java <==
package org.chorem.lima.ui.common;

/*
 * #%L
 * Lima :: Swing
 * $Id: CellRouteVerticalAction.java 3695 2013-07-10 09:11:39Z athimel $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.7/lima-swing/src/main/java/org/chorem/lima/ui/common/CellRouteVerticalAction.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import javax.swing.*;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class CellRouteVerticalAction extends CellRouteHorizontalAction {

    public CellRouteVerticalAction(JTable table, boolean nextCell) {
        super(table, nextCell);
    }

    protected void init() {
        route1 = table.getSelectedRow();
        route2 = table.getSelectedColumn();
        nbCell1 = table.getRowCount();
        nbCell2 = table.getColumnCount();
    }

    protected int getRow() {
        return route1;
    }

    protected int getColumn() {
        return route2;
    }

}

==> lima-swing-0.7.1-sources.jar: org/chorem/lima/ui/common/CellRouteVerticalAction.java <==
package org.chorem.lima.ui.common;

/*
 * #%L
 * Lima :: Swing
 * $Id: CellRouteVerticalAction.java 3695 2013-07-10 09:11:39Z athimel $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.1/lima-swing/src/main/java/org/chorem/lima/ui/common/CellRouteVerticalAction.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import javax.swing.*;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class CellRouteVerticalAction extends CellRouteHorizontalAction {

    public CellRouteVerticalAction(JTable table, boolean nextCell) {
        super(table, nextCell);
    }

    protected void init() {
        route1 = table.getSelectedRow();
        route2 = table.getSelectedColumn();
        nbCell1 = table.getRowCount();
        nbCell2 = table.getColumnCount();
    }

    protected int getRow() {
        return route1;
    }

    protected int getColumn() {
        return route2;
    }

}
